django-subdomains
=================
FOR OF django-subdomains to work with Python 3.7 and Django 2.1.x
Subdomain helpers for the Django framework, including subdomain-based URL
routing and reversing.

Old Full documentation can be found here: http://django-subdomains.readthedocs.org/

Build Status
------------

.. image:: https://travis-ci.org/kpavlovsky/django-subdomains?branch=master
   :target: https://travis-ci.org/kpavlovsky/django-subdomains

Tested on Python 3.7 on their supported Django versions 2.1.x
